@@ -116,12 +116,6 @@ namespace internal {
       _timeRcv = now;
       _dnlNow = dlnow;
     }
-    else if ( !_dnlNow && !_dnlTotal )
-    {
-      // Start time counting as soon as first data arrives.
-      // Skip the connection / redirection time at begin.
-      return;
-    }
 
     // init or reset if time jumps back
     if ( !_timeStart || _timeStart > now )
@@ -618,7 +612,9 @@ void MediaCurl::disconnectFrom()
 
   if ( _curl )
   {
-    curl_easy_cleanup( _curl );
+    // bsc#1201092: Strange but within global_dtors we may exceptions here.
+    try { curl_easy_cleanup( _curl ); }
+    catch (...) { ; }
     _curl = NULL;
   }
 }
