@@ -609,9 +609,7 @@ namespace zypp
               }
               break;
 
-            case CapDetail::REL_NONE:
-            case CapDetail::CAP_WITH:
-            case CapDetail::CAP_ARCH:
+            default:
               break; // unwanted
           }
         }
