@@ -256,7 +256,7 @@ SATResolver::dumpOn( std::ostream & os ) const
         OUTS( ALLOW_UNINSTALL );
         OUTS( NO_UPDATEPROVIDE );
         OUTS( SPLITPROVIDES );
-        OUTS( IGNORE_RECOMMENDED );
+        OUTS( ONLY_NAMESPACE_RECOMMENDED );
         OUTS( ADD_ALREADY_RECOMMENDED );
         OUTS( NO_INFARCHCHECK );
         OUTS( KEEP_EXPLICIT_OBSOLETES );
@@ -369,7 +369,7 @@ SATSolutionToPool (PoolItem item, const ResStatus & status, const ResStatus::Tra
 /// On the fly it clears all PoolItem bySolver/ByApplLow status.
 /// The lists are cleared in the Ctor, populated by \ref operator().
 /////////////////////////////////////////////////////////////////////////
-struct SATCollectTransact : public resfilter::PoolItemFilterFunctor
+struct SATCollectTransact
 {
   SATCollectTransact( PoolItemList & items_to_install_r,
                       PoolItemList & items_to_remove_r,
@@ -436,7 +436,7 @@ private:
 //----------------------------------------------------------------------------
 
 
-class CheckIfUpdate : public resfilter::PoolItemFilterFunctor
+class CheckIfUpdate
 {
   public:
     bool is_updated;
@@ -596,7 +596,7 @@ SATResolver::solving(const CapabilitySet & requires_caps,
         invokeOnEach( _pool.byIdentBegin( poolItem ),
                       _pool.byIdentEnd( poolItem ),
                       resfilter::ByUninstalled(),			// ByUninstalled
-                      functor::functorRef<bool,PoolItem> (info) );
+                      std::ref(info) );
 
         if (info.is_updated) {
           SATSolutionToPool( poolItem, ResStatus::toBeUninstalledDueToUpgrade, ResStatus::SOLVER );
@@ -689,7 +689,7 @@ SATResolver::solverInit(const PoolItemList & weakItems)
     // clear and rebuild: _items_to_install, _items_to_remove, _items_to_lock, _items_to_keep
     {
       SATCollectTransact collector( _items_to_install, _items_to_remove, _items_to_lock, _items_to_keep, solveSrcPackages() );
-      invokeOnEach ( _pool.begin(), _pool.end(), functor::functorRef<bool,PoolItem>( collector ) );
+      invokeOnEach ( _pool.begin(), _pool.end(), std::ref( collector ) );
     }
 
     for (PoolItemList::const_iterator iter = weakItems.begin(); iter != weakItems.end(); iter++) {
@@ -948,7 +948,7 @@ void SATResolver::doUpdate()
             invokeOnEach( _pool.byIdentBegin( poolItem ),
                           _pool.byIdentEnd( poolItem ),
                           resfilter::ByUninstalled(),			// ByUninstalled
-                          functor::functorRef<bool,PoolItem> (info) );
+                          std::ref(info) );
 
             if (info.is_updated) {
                 SATSolutionToPool (poolItem, ResStatus::toBeUninstalledDueToUpgrade , ResStatus::SOLVER);
@@ -981,7 +981,7 @@ void SATResolver::doUpdate()
 // helper function
 //----------------------------------------------------------------------------
 
-struct FindPackage : public resfilter::ResObjectFilterFunctor
+struct FindPackage
 {
     ProblemSolutionCombi *problemSolution;
     TransactionKind action;
@@ -1371,7 +1371,7 @@ SATResolver::problems ()
                                               _pool.byIdentEnd( ident ),
                                               functor::chain (resfilter::ByInstalled (),			// ByInstalled
                                                               resfilter::ByTransact ()),			// will be deinstalled
-                                              functor::functorRef<bool,PoolItem> (info) );
+                                              std::ref(info) );
 
                                 SolverQueueItemDelete_Ptr del =
                                     new SolverQueueItemDelete(_pool, ident.asString(), false );
